@@ -6,6 +6,7 @@
 #include <libbiji/libbiji.h>
 #include <libgd/gd.h>
 
+#include "bjb-app-menu.h"
 #include "bjb-bijiben.h"
 #include "bjb-empty-results-box.h"
 #include "bjb-window-base.h"
@@ -137,6 +138,59 @@ bjb_window_base_set_property (GObject  *object,
 
 
 
+static gboolean
+on_key_pressed_cb (GtkWidget *w, GdkEvent *event, gpointer user_data)
+{
+  BjbWindowBase *self = BJB_WINDOW_BASE (user_data);
+  BjbWindowBasePriv *priv = self->priv;
+  GdkModifierType modifiers;
+
+  modifiers = gtk_accelerator_get_default_mod_mask ();
+
+  /* First check for Alt <- to go back */
+  if ((event->key.state & modifiers) == GDK_MOD1_MASK &&
+      event->key.keyval == GDK_KEY_Left &&
+      priv->current_view == BJB_WINDOW_BASE_NOTE_VIEW)
+  {
+    BijiItemsGroup items;
+
+    items = bjb_controller_get_group (priv->controller);
+    if (items == BIJI_LIVING_ITEMS)
+      bjb_window_base_switch_to (self, BJB_WINDOW_BASE_MAIN_VIEW);
+
+    else if (items == BIJI_ARCHIVED_ITEMS)
+      bjb_window_base_switch_to (self, BJB_WINDOW_BASE_ARCHIVE_VIEW);
+
+    return TRUE;
+  }
+
+
+  switch (event->key.keyval)
+  {
+    /* Help on F1 */
+    case GDK_KEY_F1:
+      help_activated (NULL, NULL, NULL);
+      return TRUE;
+
+    /* Reserve other func keys for window */
+    case GDK_KEY_F2:
+    case GDK_KEY_F3:
+    case GDK_KEY_F4:
+    case GDK_KEY_F5:
+    case GDK_KEY_F6:
+    case GDK_KEY_F7:
+    case GDK_KEY_F8:
+    case GDK_KEY_F9:
+    case GDK_KEY_F10:
+    case GDK_KEY_F11:
+      return TRUE;
+
+    default:
+      return FALSE;
+  }
+
+  return FALSE;
+}
 
 
 
@@ -316,6 +370,9 @@ bjb_window_base_constructed (GObject *obj)
   gtk_stack_add_named (priv->stack, GTK_WIDGET (priv->view), "main-view");
   gtk_widget_show (GTK_WIDGET (priv->stack));
 
+
+  /* Connection to window signals */
+
   g_signal_connect (GTK_WIDGET (self),
                     "destroy",
                     G_CALLBACK (bjb_window_base_destroy),
@@ -331,6 +388,13 @@ bjb_window_base_constructed (GObject *obj)
                     G_CALLBACK (bjb_application_window_configured),
                     self);
 
+  /* Keys */
+
+  g_signal_connect (GTK_WIDGET (self),
+                    "key-press-event",
+                    G_CALLBACK(on_key_pressed_cb),
+		    self);
+
   /* If a note is requested at creation, show it
    * This is a specific type of window not associated with any view */
   if (priv->note == NULL)
